@@ -366,7 +366,7 @@ class Insight_Definition:
 
     def edit_chart(self, chart_id, chart_type:str, query:str, params, title = "Chart"):
 
-        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/"+query.lower()+"/columns"
+        '''url = self._base_url_askdata+"/smartinsight/definitions/"+self.definition_id+"/queries/"+query.lower()+"/columns"
 
         s = requests.Session()
         s.keep_alive = False
@@ -381,10 +381,44 @@ class Insight_Definition:
         r.raise_for_status()
         columns = r.json()
 
+        while(columns == []):
+            url = self._base_url_askdata + "/smartinsight/definitions/" + self.definition_id + "/queries/" + query.lower() + "/columns"
+
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
+
+            headers = {
+                "Content-Type": "application/json",
+                "Authorization": "Bearer" + " " + self._token
+            }
+            r = s.get(url=url, headers=headers)
+            r.raise_for_status()
+            columns = r.json()
+        '''
+
+        qc = self.get_component(query)
+
+        url_preview = self.smart_insight_url+"/composed_queries/"+qc["settings"]["qc"]+"/preview?limit=100"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=url_preview, json={}, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+        columns = r["schema"]
+
+        print(columns)
+
         upper_params = []
         for param in params:
             for column in columns:
-                if param in column["code"]:
+                if((param in column["code"]) or (param == column["code"])):
                     upper_params.append(column["code"])
 
         url = self.smart_insight_url + "/definitions/" + self.definition_id + "/charts/" + chart_id
@@ -497,7 +531,6 @@ class Insight_Definition:
         r.raise_for_status()
         response = r.json()
 
-        print("RESPONSE 1 {}".format(response))
         right_fields = []
         left_fields = []
         for field in new_qc["fields"]:
@@ -509,8 +542,6 @@ class Insight_Definition:
 
         joinable_fields = response["joinedSmartQuery"]["joinableFields"]
 
-
-
         qc["joinedSmartQuery"]["smartQueryId"] = new_qc["id"]
         qc["joinedSmartQuery"]["joinType"] = type.upper()
         qc["joinedSmartQuery"]["leftFields"] = left_fields
@@ -544,7 +575,9 @@ class Insight_Definition:
                     return component
 
     def add_query_composer(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
+
         qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)["id"]
+
         position = (len(self.components))
         qc_post_url = self.smart_insight_url + "/definitions/" + self.definition_id + "/query_composers"
 
@@ -558,11 +591,12 @@ class Insight_Definition:
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.post(url=qc_post_url, json=body, headers=headers)
         response.raise_for_status()
-        r = response.json()
-        self.components = r["components"]
+        query = response.json()
+        self.components = query["components"]
+
         return {
             "qc_id": qc_id,
-            "component_id": r["components"][position]["id"]
+            "component_id": query["components"][position]["id"]
         }
 
 
